@@ -4,6 +4,7 @@ __all__ = (
     "AbstractBytSubmittableMeter",
     "AccountWithBytBalance",
     "AccountWithBytIndications",
+    "AccountWithBytInfo",
     "AccountWithBytInfoFromDouble",
     "AccountWithBytInfoFromSingle",
     "AccountWithBytInvoices",
@@ -12,6 +13,7 @@ __all__ = (
     "AccountWithBytTariffHistory",
     "AccountWithStaticBytProxy",
     "BytAccountBase",
+    "BytAccountWithInfoBase",
     "BytBalance",
     "BytCheckupStatus",
     "BytIndication",
@@ -22,6 +24,7 @@ __all__ = (
     "BytMeterZoneContainer",
     "BytPayment",
     "BytTariffHistoryEntry",
+    "BytZoneInfoContainer",
     "WithBytProxy",
     "WithStaticBytProxy",
 )
@@ -32,10 +35,12 @@ from datetime import date, datetime
 from types import MappingProxyType
 from typing import (
     Any,
+    Dict,
     Generic,
     List,
     Mapping,
     Optional,
+    Sequence,
     SupportsFloat,
     TYPE_CHECKING,
     Tuple,
@@ -60,15 +65,6 @@ from inter_rao_energosbyt.actions.sql.byt import (
     SaveIndications,
     TariffHistory,
 )
-from inter_rao_energosbyt.presets.containers import (
-    BalanceContainer,
-    IndicationContainer,
-    InvoiceContainer,
-    MeterContainer,
-    MeterZoneContainer,
-    TariffHistoryEntry,
-    ZoneHistoryEntry,
-)
 from inter_rao_energosbyt.const import META_DISPLAY_NAME
 from inter_rao_energosbyt.converters import (
     conv_float_optional,
@@ -84,17 +80,24 @@ from inter_rao_energosbyt.interfaces import (
     AbstractAccountWithPayments,
     AbstractAccountWithTariffHistory,
     AbstractCalculatableMeter,
-    AbstractSubmittableMeter,
     AbstractPayment,
+    AbstractSubmittableMeter,
     Account,
     WithAccount,
-    WithCalculateIndications,
+)
+from inter_rao_energosbyt.presets.containers import (
+    BalanceContainer,
+    IndicationContainer,
+    InvoiceContainer,
+    MeterContainer,
+    MeterZoneContainer,
+    TariffHistoryEntry,
+    ZoneHistoryEntry,
 )
 from inter_rao_energosbyt.util import AnyDateArg, process_start_end_arguments
 
 if TYPE_CHECKING:
-    # noinspection PyUnresolvedReferences
-    from inter_rao_energosbyt.proxy.byt import _LSInfoBase
+    from inter_rao_energosbyt.actions.sql.byt import _LSInfoBase
 
 _TAccount = TypeVar("_TAccount", bound=Account)
 
@@ -171,7 +174,7 @@ class BytPayment(AbstractPayment, WithAccount["AccountWithBytPayments"]):
     account: "AccountWithBytPayments" = attr.ib(repr=False)
     paid_at: "datetime" = attr.ib()
     amount: float = attr.ib(converter=float)
-    state: Optional[str] = attr.ib(converter=conv_str_optional, default=None)
+    status: Optional[str] = attr.ib(converter=conv_str_optional, default=None)
 
     @classmethod
     def from_response(cls, account: "AccountWithBytPayments", data: Pays):
@@ -181,12 +184,12 @@ class BytPayment(AbstractPayment, WithAccount["AccountWithBytPayments"]):
             account=account,
             paid_at=paid_at,
             amount=amount,
-            state=data.nm_status,
+            status=data.nm_status,
         )
 
     @property
     def is_accepted(self) -> bool:
-        return self.state == "Зачислен"
+        return self.status == "Зачислен"
 
 
 class AccountWithBytPayments(WithBytProxy, AbstractAccountWithPayments[BytPayment], ABC):
@@ -286,7 +289,7 @@ class AccountWithBytIndications(WithBytProxy, AbstractAccountWithIndications[Byt
             return from_response(self, response_item)
 
         # @TODO: add meter code
-        if isinstance(self, _AccountWithBytInfo):
+        if isinstance(self, AccountWithBytInfo):
             info = self.info
             if info is None:
                 info = await self.async_update_info()
@@ -304,17 +307,130 @@ class AccountWithBytIndications(WithBytProxy, AbstractAccountWithIndications[Byt
         return list(map(_create_indication, response))
 
 
-@attr.s(kw_only=False, frozen=True, slots=True)
+BYT_INVOICE_SECTION = "byt_invoice_section"
+
+
+@attr.s(kw_only=True, frozen=True, slots=True)
+class BytInvoiceDetail:
+    name: str = attr.ib(converter=str)
+    total: float = attr.ib(converter=float)
+    currency: str = attr.ib(converter=str)
+    value: float = attr.ib(converter=float)
+    value_unit: str = attr.ib(converter=str)
+    tariff: float = attr.ib(converter=float)
+    tariff_unit: str = attr.ib(converter=str)
+
+
+@attr.s(kw_only=True, frozen=True, slots=True)
 class BytInvoice(InvoiceContainer, WithAccount["AccountWithBytInvoices"]):
     account: "AccountWithBytInvoices" = attr.ib(repr=False)
+    excess_initial: Optional[float] = attr.ib(
+        converter=conv_float_optional,
+        default=None,
+        metadata={BYT_INVOICE_SECTION: "Сумма переплаты на начало периода"},
+    )
+    excess_total: Optional[float] = attr.ib(
+        converter=conv_float_optional,
+        default=None,
+        metadata={BYT_INVOICE_SECTION: "Итого переплата"},
+    )
+    debt_initial: Optional[float] = attr.ib(
+        converter=conv_float_optional,
+        default=None,
+        metadata={BYT_INVOICE_SECTION: "Сумма задолженности на начало периода"},
+    )
+    paid: Optional[float] = attr.ib(
+        converter=conv_float_optional,
+        default=None,
+        metadata={BYT_INVOICE_SECTION: "Сумма поступивших платежей, учтенных при расчете"},
+    )
+    penalty_charged: Optional[float] = attr.ib(
+        converter=conv_float_optional,
+        default=None,
+        metadata={BYT_INVOICE_SECTION: "Начислено пени"},
+    )
+    penalty_paid: Optional[float] = attr.ib(
+        converter=conv_float_optional,
+        default=None,
+        metadata={BYT_INVOICE_SECTION: "в т.ч.оплачено пени"},
+    )
+    penalty_total: Optional[float] = attr.ib(
+        converter=conv_float_optional,
+        default=None,
+        metadata={BYT_INVOICE_SECTION: "в т.ч.пени"},
+    )
+    penalty_initial: Optional[float] = attr.ib(
+        converter=conv_float_optional,
+        default=None,
+        metadata={BYT_INVOICE_SECTION: "в т.ч.пени на начало периода"},
+    )
+    charged: Optional[float] = attr.ib(
+        converter=conv_float_optional,
+        default=None,
+        metadata={BYT_INVOICE_SECTION: "Всего начислено за текущий период"},
+    )
+    recalculations: Optional[float] = attr.ib(
+        converter=conv_float_optional,
+        default=None,
+        metadata={BYT_INVOICE_SECTION: "Перерасчеты"},
+    )
+    pay_total: Optional[float] = attr.ib(
+        converter=conv_float_optional,
+        default=None,
+        metadata={BYT_INVOICE_SECTION: "Итого к оплате"},
+    )
+    benefits: Optional[float] = attr.ib(
+        converter=conv_float_optional,
+        default=None,
+        metadata={BYT_INVOICE_SECTION: "Льготы"},
+    )
+    details: Sequence[BytInvoiceDetail] = attr.ib(converter=tuple, factory=tuple)
+
+    @classmethod
+    def byt_invoice_sections(cls) -> Dict[str, str]:
+        invoice_sections = {}
+        for field in attr.fields(cls):
+            invoice_section = field.metadata.get(BYT_INVOICE_SECTION)
+            if invoice_section:
+                invoice_sections[invoice_section] = field.name
+
+        return invoice_sections
 
     @classmethod
     def from_response(cls, account: "AccountWithBytInvoices", data: Invoice) -> "BytInvoice":
+        section_args = {}
+        invoice_sections = cls.byt_invoice_sections()
+        for common_data in data.data_common:
+            try:
+                section_args[invoice_sections[common_data.nm_value]] = common_data.vl_value
+            except KeyError:
+                continue
+
+        invoice_details = []
+        for detail_data_group in data.data_detail:
+            if len(detail_data_group) != 3:
+                # Safeguard to prevent errors
+                continue
+            header, counted, tariff = tuple(detail_data_group)
+            invoice_details.append(
+                BytInvoiceDetail(
+                    name=header.nm_value,
+                    total=header.vl_value,
+                    currency=header.nm_mu,
+                    value=counted.vl_value,
+                    value_unit=counted.nm_mu,
+                    tariff=tariff.vl_value,
+                    tariff_unit=tariff.nm_mu,
+                )
+            )
+
         return cls(
             account=account,
             id=data.id_korr,
             total=data.sm_total,
             period=datetime.fromisoformat(data.dt_period).date(),
+            details=invoice_details,
+            **section_args,
         )
 
 
@@ -360,6 +476,27 @@ def repr_helper(obj: object, *props: property, name: Optional[str] = None) -> st
     return "<" + name + "(" + values + ")>"
 
 
+@attr.s(kw_only=True, frozen=True, slots=True)
+class BytZoneInfoContainer:
+    name: str = attr.ib()
+    description: str = attr.ib()
+    tariff: float = attr.ib(converter=float)
+    within_name: Optional[str] = attr.ib(converter=conv_str_optional, default=None)
+    within_description: str = attr.ib(converter=conv_str_optional, default=None)
+    within_tariff: Optional[float] = attr.ib(converter=conv_float_optional, default=None)
+
+    @classmethod
+    def from_info(cls, ls_info: "_LSInfoBase", zone_id: str):
+        return cls(
+            name=getattr(ls_info, f"nm_{zone_id}"),
+            description=getattr(ls_info, f"nm_{zone_id}_description"),
+            tariff=getattr(ls_info, f"vl_{zone_id}_tariff"),
+            within_name=getattr(ls_info, f"nm_{zone_id}_within", None),
+            within_description=getattr(ls_info, f"nm_{zone_id}_description_within", None),
+            within_tariff=getattr(ls_info, f"vl_{zone_id}_tariff_within", None),
+        )
+
+
 class _BytInfo(ABC, Generic[_TLSInfoBase]):
     __slots__ = ("_ls_info",)
 
@@ -430,6 +567,14 @@ class _BytInfo(ABC, Generic[_TLSInfoBase]):
     def checkup_year(self) -> Optional[int]:
         return self._ls_info.mpi_year
 
+    @property
+    def zones(self) -> Optional[Mapping[str, BytZoneInfoContainer]]:
+        ls_info = self._ls_info
+        return {
+            zone_id: BytZoneInfoContainer.from_info(ls_info, zone_id)
+            for zone_id in _extract_numerical_zone_ids(ls_info)
+        }
+
 
 class BytInfoSingle(_BytInfo[LSInfo]):
     __slots__ = ()
@@ -527,7 +672,7 @@ class BytInfoDouble(_BytInfo[LsInfo]):
 _TBytInfo = TypeVar("_TBytInfo", bound=_BytInfo)
 
 
-class _AccountWithBytInfo(WithBytProxy, Account, ABC, Generic[_TBytInfo]):
+class AccountWithBytInfo(WithBytProxy, Account, ABC, Generic[_TBytInfo]):
     __slots__ = ()
 
     @property
@@ -535,24 +680,28 @@ class _AccountWithBytInfo(WithBytProxy, Account, ABC, Generic[_TBytInfo]):
     def info(self) -> _TBytInfo:
         pass
 
+    @abstractmethod
+    async def async_get_info(self) -> _TBytInfo:
+        pass
+
     @abstractmethod
     async def async_update_info(self) -> _TBytInfo:
         pass
 
 
-class AccountWithBytInfoFromSingle(_AccountWithBytInfo[BytInfoSingle], ABC):
+class AccountWithBytInfoFromSingle(AccountWithBytInfo[BytInfoSingle], ABC):
     __slots__ = ()
 
-    async def async_update_info(self) -> BytInfoSingle:
+    async def async_get_info(self) -> BytInfoSingle:
         proxy, provider = await self._internal_async_prepare_byt_preset_parameters()
         response = await LSInfo.async_request(self.api, proxy, provider)
         return BytInfoSingle(response)
 
 
-class AccountWithBytInfoFromDouble(_AccountWithBytInfo[BytInfoDouble], ABC):
+class AccountWithBytInfoFromDouble(AccountWithBytInfo[BytInfoDouble], ABC):
     __slots__ = ()
 
-    async def async_update_info(self) -> BytInfoDouble:
+    async def async_get_info(self) -> BytInfoDouble:
         proxy, provider = await self._internal_async_prepare_byt_preset_parameters()
         api = self.api
 
@@ -595,7 +744,9 @@ class BytMeter(MeterContainer, WithAccount["AccountWithBytMeters"]):
 
     @classmethod
     def from_response(
-        cls: Type[_TBytMeter], account: "AccountWithBytMeters", data: "Meters"
+        cls: Type[_TBytMeter],
+        account: "AccountWithBytMeters",
+        data: "Meters",
     ) -> _TBytMeter:
         zone_ids = _extract_numerical_zone_ids(data)
         zones = {
@@ -674,8 +825,8 @@ class AbstractBytSubmittableMeter(
                 value = zone.last_indication or 0.0
             data["vl_" + zone_id] = value
 
-        if kwargs:
-            raise TypeError("meter does not support extra zones: " + ", ".join(kwargs))
+        if any(kwargs.values()):
+            raise EnergosbytException("meter does not support extra zones: " + ", ".join(kwargs))
 
         account = self.account
 
@@ -919,16 +1070,7 @@ class AccountWithBytTariffHistory(
         return await self.async_get_byt_tariff_history()
 
 
-class BytAccountBase(
-    AccountWithBytMeters,
-    AccountWithBytPayments,
-    AccountWithBytInvoices,
-    AccountWithBytIndications,
-    AccountWithBytBalance,
-    AccountWithBytTariffHistory,
-    _AccountWithBytInfo,
-    ABC,
-):
+class BytAccountWithInfoBase(AccountWithBytInfo, ABC):
     __slots__ = ("_info",)
 
     def __init__(self, *args, **kwargs) -> None:
@@ -936,5 +1078,23 @@ class BytAccountBase(
         self._info = None
 
     @property
-    def info(self):
+    def info(self) -> "_LSInfoBase":
         return self._info
+
+    async def async_update_info(self) -> _TBytInfo:
+        ls_info = await self.async_get_info()
+        self._info = ls_info
+        return ls_info
+
+
+class BytAccountBase(
+    AccountWithBytMeters,
+    AccountWithBytPayments,
+    AccountWithBytInvoices,
+    AccountWithBytIndications,
+    AccountWithBytBalance,
+    AccountWithBytTariffHistory,
+    BytAccountWithInfoBase,
+    ABC,
+):
+    __slots__ = ()
